@@ -36,10 +36,13 @@ from _libsemigroups_pybind11 import (
     wilo,
     wislo,
     Sims1,
+    Kambites,
+    Stephen,
 )
 
 from .froidure_pin import FroidurePin
+from .konieczny import Konieczny
 from .matrix import Matrix, MatrixKind, make_identity
 from .presentation import Presentation, redundant_rule
 from .tools import libsemigroups_version
-from .transf import Transf
+from .transf import Transf, PPerm
